==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/bd/hbd91.h <==
/****************************************************************************

  module      : hbd91.h

  -------------------------------------------------------------------------

  responsible : AlexanderK

  special area: 
  description : Declaration of exported functions of modul vbd91.cpp


  version     : 7.2.0.0
  last changed: 1999-07-28  19:48
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*****************************************************************************/

#ifndef HBD91_H
#define HBD91_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gbd900.h"
#include "gbd94.h" 
#include "gbd910.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externCpp cbd900_ObjFileInfo*
bd91AddFileToObjFileDir (tgg00_TransContext   &Trans,
						 tgg00_FileId         &FileId,
						 cbd910_RootNode      &NptrsRoot);

/*---------------------------------------------------------------------------*/

externCpp cbd900_ObjFileInfo*
bd91AddFileToContObjFileDir (tgg00_TransContext   &Trans,
							 tgg00_FileId         &FileId,
    						 cbd910_RootNode      &NptrsRoot);

/*---------------------------------------------------------------------------*/

externC void
bd91DumpGarbColl (tgg00_VfFileref     &HostFile,
                 tsp00_Int4            BufferSize,
                 tsp00_Page           &Buffer,
                 tsp00_Int4           &OutPno,
                 tsp00_Int4           &OutPos,
                 tsp00_VfReturn       &HostError,
                 tsp00_ErrText        &ErrText);

/*---------------------------------------------------------------------------*/

externC void
bd91InitObjFileDir (tgg00_TransContext &Trans);

/*---------------------------------------------------------------------------*/

externC void
bd91InitOMSGarbageCollection ();


/*---------------------------------------------------------------------------*/

externCpp void
bd91RegisterHistoryFile   (tgg00_TransContext            &Trans,
						   const tbd94_HistoryFileHandle &HistoryFileHandle);

/*---------------------------------------------------------------------------*/

externC void
bd91StartOMSGarbageCollection (tgg00_TransContext   &Trans, 
							   tsp00_Bool            bStartOnlyIfDataCacheIsFull);

/*---------------------------------------------------------------------------*/

externC void
bd91StartOMSGarbageCollectionAfterSavepoint (tgg00_TransContext   &Trans);

/*---------------------------------------------------------------------------*/

externC void
bd91StopOMSGarbageCollectionForSavepoint (tgg00_TransContext   &Trans);

/*---------------------------------------------------------------------------*/

#endif /* HBD91_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/bd/hbd91.h <==
/****************************************************************************

  module      : hbd91.h

  -------------------------------------------------------------------------

  responsible : AlexanderK

  special area: 
  description : Declaration of exported functions of modul vbd91.cpp


  version     : 7.2.0.0
  last changed: 1999-07-28  19:48
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*****************************************************************************/

#ifndef HBD91_H
#define HBD91_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gbd900.h"
#include "gbd910.h"

#include "liveCache/LVC_ErrorTraceObject.hpp"
#include "Logging/Log_UndoFile.hpp"
#include "GarbageCollector/GC_IGarbageCollector.hpp" // PTS xxxxxxx FF 2002-02-12

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externCpp cbd900_ObjFileInfo*
bd91AddFileToObjFileDir (tgg00_TransContext   &Trans,
						 tgg00_FileId         &FileId,
						 cbd910_RootNode      &NptrsRoot);

/*---------------------------------------------------------------------------*/

externCpp cbd900_ObjFileInfo*
bd91AddFileToContObjFileDir (tgg00_TransContext   &Trans,
							 tgg00_FileId         &FileId,
    						 cbd910_RootNode      &NptrsRoot);

/*---------------------------------------------------------------------------*/

externC void
bd91DumpGarbColl (tgg00_VfFileref     &HostFile,
                 tsp00_Int4            BufferSize,
                 tsp00_Page           &Buffer,
                 tsp00_Int4           &OutPno,
                 tsp00_Int4           &OutPos,
                 tsp00_VfReturn       &HostError,
                 tsp00_ErrText        &ErrText);

/*---------------------------------------------------------------------------*/
externC void
bd91InfoGCReset( void );

/*---------------------------------------------------------------------------*/

externC void
bd91InfoGCStats (tsp00_Int4            idxGC,   
                 tsp00_TaskId         &taskId,
                 tsp00_Bool           &active,
                 tsp00_8ByteCounter   &activateCount,
                 tsp00_8ByteCounter   &deleteObj,
                 tsp00_8ByteCounter   &relHistEntryNormal,
                 tsp00_8ByteCounter   &relHistCreateObjFile,
                 tsp00_8ByteCounter   &relHistDeleteObj,
                 tsp00_8ByteCounter   &relHistDropObjFile,
                 tsp00_8ByteCounter   &relHistLockObj,
                 tsp00_8ByteCounter   &relHistInsertObj,
                 tsp00_8ByteCounter   &relHistNewObj,
                 tsp00_8ByteCounter   &relHistUpdateObj,
                 tsp00_8ByteCounter   &relPageEmpty,
                 tsp00_8ByteCounter   &relPageDropFile,
                 tsp00_8ByteCounter   &relDropFile );

/*---------------------------------------------------------------------------*/

externC void
bd91InitObjFileDir (tgg00_TransContext &Trans);

/*---------------------------------------------------------------------------*/

externC void
bd91InitOMSGarbageCollection ();

/*---------------------------------------------------------------------------*/

externC tsp_int4 b91MaxRetentionTime();
 
/*---------------------------------------------------------------------------*/

externC tsp_int4 b91MinRetentionTime();

/*---------------------------------------------------------------------------*/
// PTS 1113635 FF 25-Jan-2002
externC void
bd91MigrateObjFile (tgg00_TransContext  &Trans,
                    tgg00_FileId        &ObjFileId);

/*---------------------------------------------------------------------------*/
// PTS 1113635 FF 25-Jan-2002
externC tsp00_Int4
bd91MigrationNeeded( tsp00_Version &version );

/*---------------------------------------------------------------------------*/
// PTS 1113452 FF 16-Jan-2002

externC void
bd91RemoveObjFilesMarkedForDelete (tgg00_TransContext &Trans);

/*---------------------------------------------------------------------------*/

externC void
bd91StartOMSGarbageCollection (tgg00_TransContext   &Trans, 
                               tsp00_Bool            bIfGCWaitTimeDone);

/*---------------------------------------------------------------------------*/

externC void
bd91StartOMSGarbageCollectionAfterSpecialOp (tsp00_TaskId  TaskId);

/*---------------------------------------------------------------------------*/

externC void
bd91StopOMSGarbageCollectionForSpecialOp (tsp00_TaskId  TaskId);

/*---------------------------------------------------------------------------*/
// PTS 1116157 FF 2002-06-07
externC void
bd91StartOMSGarbageCollectionIfRequired (tgg00_TransContext   &Trans); 

/*---------------------------------------------------------------------------*/

externCpp void
bd91RemoveObjFromFile (tbd_current_tree        &Current,
                       cbd910_PrimObjDataNode  &NptrsPage,
					   cbd910_SubRootNode      &NptrsSubRoot,
                       tbd900_ObjFrame         *pObjFrame,
                       tgg92_KernelOid         &OId,
                       cbd900_ObjFileInfo      &ObjFileInfo, 
                       Log_UndoFile::Iterator  &historyIterator,
                       LVC_ErrorTraceObject    &ErrorTraceObject);

/*---------------------------------------------------------------------------*/

externCpp void
bd91RemoveObjFromPage (tbd_current_tree        &Current,
					   cbd910_PrimObjDataNode  &NptrsPage,
					   tbd900_ObjFrame         *pObjFrame,
                       tgg92_KernelOid         &OId,
					   cbd900_ObjFileInfo      &ObjFileInfo, 
					   LVC_ErrorTraceObject    &ErrorTraceObject);

/*---------------------------------------------------------------------------*/

externCpp void
bd91ReleaseUnusedObject ( tgg00_TransContext      &Trans,
                          Log_UndoFile::Iterator  &historyIterator,
                          const tgg92_KernelOid   &OId,
                          tgg00_ObjFileNo          ObjFileNo,
                          const tgg91_PageRef     &WantedObjVers,
                          GC_IGarbageCollector    &IGarbColl);

/*---------------------------------------------------------------------------*/

#endif /* HBD91_H */
